# Attributions

This document lists the attributions for external assets used in the Space Robotics Bench.

## Models

In addition to modifications listed below, all models have been converted to the [Universal Scene Description (USD)](https://openusd.org) format with non-destructive transformations.

1. [Gateway Lunar Space Station](https://nasa3d.arc.nasa.gov/detail/gateway) by NASA's Gateway Program Office
   - Separated into individual assets (Gateway Core, Canadarm3)
1. [Mars 2020 Sample Tube](https://nasa3d.arc.nasa.gov/detail/Mars-2020-Sample-Tube-3D-print-files) by JPL-Caltech
   - Added mesh of the sample tube cap
   - Added materials
1. [Mars Ingenuity Helicopter](https://science.nasa.gov/resource/mars-ingenuity-helicopter-3d-model) by NASA/JPL-Caltech
1. [Mars Perseverance Rover](https://science.nasa.gov/resource/mars-perseverance-rover-3d-model) by NASA/JPL-Caltech
1. [Starship](https://www.blendswap.com/blend/27853) by gallus-gallus licensed under [CC0 1.0](https://creativecommons.org/publicdomain/zero/1.0)
   - Recreated materials
1. [Super Heavy](https://www.blendswap.com/blend/27853) by gallus-gallus licensed under [CC0 1.0](https://creativecommons.org/publicdomain/zero/1.0)
   - Changed number and location of engines
   - Recreated materials
1. [Oberpfaffenhofen Moon Mars Test Site](https://doi.org/10.5281/zenodo.15145192) by DLR licensed under [CC BY-SA 4.0](https://creativecommons.org/licenses/by-sa/4.0)
   - Cleaned up the boundaries of the terrain
   - Removed disconnected geometry

## Images

Where applicable, [EXR](https://www.openexr.com) images have been DWAA compressed.

1. [Earth From Space](https://www.blenderkit.com/asset-gallery-detail/aaed845b-70f9-40b1-a1ba-41cc10c58249/) by EB Adventure Photoscans licensed under [RF](https://www.blenderkit.com/docs/licenses)
1. [Low Lunar Orbit](https://nasa3d.arc.nasa.gov/detail/gateway) by NASA's Gateway Program Office
1. [Sunflowers (Pure Sky)](https://polyhaven.com/a/overcast_soil_puresky) by Sergej Majboroda and Jarod Guest licensed under [CC0 1.0](https://creativecommons.org/publicdomain/zero/1.0)
1. [The bright star foreground in celestial coordinates](https://svs.gsfc.nasa.gov/4851/#media_group_319121) by NASA/Goddard Space Flight Center Scientific Visualization Studio
1. [The Milky Way background in celestial coordinates](https://svs.gsfc.nasa.gov/4851/#media_group_319120) by NASA/Goddard Space Flight Center Scientific Visualization Studio
